@@ -69,8 +69,6 @@ func NewStore(d Dialect) (Store, error) {
 		querier = &dialectquery.Ydb{}
 	case Turso:
 		querier = &dialectquery.Turso{}
-	case Duckdb:
-		querier = &dialectquery.Duckdb{}
 	default:
 		return nil, fmt.Errorf("unknown querier dialect: %v", d)
 	}
