@@ -116,16 +116,14 @@ func newProvider(
 	for version, m := range cfg.registered {
 		versionToGoMigration[version] = m
 	}
-	// Return an error if the global registry is explicitly disabled, but there are registered Go
-	// migrations.
+	// Skip adding global Go migrations if explicitly disabled.
 	if cfg.disableGlobalRegistry {
-		if len(global) > 0 {
-			return nil, errors.New("global registry disabled, but provider has registered go migrations")
-		}
+		// TODO(mf): let's add a warn-level log here to inform users if len(global) > 0. Would like
+		// to add this once we're on go1.21 and leverage the new slog package.
 	} else {
 		for version, m := range global {
 			if _, ok := versionToGoMigration[version]; ok {
-				return nil, fmt.Errorf("global go migration with version %d previously registered with provider", version)
+				return nil, fmt.Errorf("global go migration conflicts with provider-registered go migration with version %d", version)
 			}
 			versionToGoMigration[version] = m
 		}
